Crate bitcoinsv_rpc_json

Crate bitcoinsv_rpc_json 

Rust Client for Bitcoin SV API

This is a client library for the Bitcoin SV JSON-RPC API.

This library is not expected to be used directly, it is a sub-component of the bitcoinsv-rpc crate. You probably want the bitcoinsv-rpc crate.

Modules

serde_hex
A module used for serde serialization of bytes in hexadecimal format.

Structs

CreateRawTransactionInput
DecodeRawTransactionResult
Model for decode transaction
GetAddedNodeInfoResult
GetAddedNodeInfoResultAddress
GetBlockHeaderResult
GetBlockResult
GetBlockResultStatus
GetBlockStatsResult
GetBlockStatsResultPartial
GetBlockchainInfoResult
Models the result of “getblockchaininfo”
GetChainTipsResultTip
Models a single chain tip for the result of “getchaintips”
GetMempoolEntryResult
GetMempoolInfoResult
GetMiningInfoResult
GetNetTotalsResult
GetNetTotalsResultUploadTarget
GetNetworkInfoResult
GetNetworkInfoResultAddress
GetNetworkInfoResultNetwork
GetPeerInfoResult
Models the result of “getpeerinfo”
GetPeerInfoResultStream
GetRawTransactionResult
GetRawTransactionResultVin
GetRawTransactionResultVinScriptSig
GetRawTransactionResultVout
GetRawTransactionResultVoutScriptPubKey
GetTxOutResult
GetTxOutSetInfoResult
ListBannedResult

Enums

BlockStatsFields
GetAddedNodeInfoResultAddressType
GetChainTipsResultStatus
HashOrHeight
Used to specify a block hash or a height
ScriptPubkeyType
TxOutSetHashType
Used to represent UTXO set hash type

Type Aliases

GetChainTipsResult
Models the result of “getchaintips”