Rust Client for Bitcoin SV API
This is a client library for the Bitcoin SV JSON-RPC API.
This library is not expected to be used directly, it is a sub-component of the bitcoinsv-rpc crate. You probably want the bitcoinsv-rpc crate.
Modules
- serde_
hex - A module used for serde serialization of bytes in hexadecimal format.
Structs
- Create
RawTransaction Input - Decode
RawTransaction Result - Model for decode transaction
- GetAdded
Node Info Result - GetAdded
Node Info Result Address - GetBlock
Header Result - GetBlock
Result - GetBlock
Result Status - GetBlock
Stats Result - GetBlock
Stats Result Partial - GetBlockchain
Info Result - Models the result of “getblockchaininfo”
- GetChain
Tips Result Tip - Models a single chain tip for the result of “getchaintips”
- GetMempool
Entry Result - GetMempool
Info Result - GetMining
Info Result - GetNet
Totals Result - GetNet
Totals Result Upload Target - GetNetwork
Info Result - GetNetwork
Info Result Address - GetNetwork
Info Result Network - GetPeer
Info Result - Models the result of “getpeerinfo”
- GetPeer
Info Result Stream - GetRaw
Transaction Result - GetRaw
Transaction Result Vin - GetRaw
Transaction Result VinScript Sig - GetRaw
Transaction Result Vout - GetRaw
Transaction Result Vout Script PubKey - GetTx
OutResult - GetTx
OutSet Info Result - List
Banned Result
Enums
- Block
Stats Fields - GetAdded
Node Info Result Address Type - GetChain
Tips Result Status - Hash
OrHeight - Used to specify a block hash or a height
- Script
Pubkey Type - TxOut
SetHash Type - Used to represent UTXO set hash type
Type Aliases
- GetChain
Tips Result - Models the result of “getchaintips”